from setuptools import setup

setup(
    name='env-file',
    version='2020.5.9',
    install_requires=[
        'public',
        'setuptools',
        'values',
    ],
    packages=[
        'env_file',
    ],
)
